package com.common.commonlib.net

import com.common.commonlib.net.interceptor.BaseUrlInterceptor
import com.common.commonlib.net.interceptor.HttpCommonInterceptor
import okhttp3.OkHttpClient
import retrofit2.Retrofit
import retrofit2.adapter.rxjava2.RxJava2CallAdapterFactory
import retrofit2.converter.gson.GsonConverterFactory
import java.util.concurrent.TimeUnit

/**
 * 网络请求管理器
 */
enum class RequestManager {
    INSTANCE;

    /**
     * 默认超时时间
     */
    private val defaultTimeOut: Long = 5

    /**
     * 默认读取超时时间
     */
    private val defaultReadTimeOut: Long = 10

    private var mRetrofit: Retrofit? = null

    init {
        val builder: OkHttpClient.Builder = OkHttpClient.Builder()
        builder.connectTimeout(defaultTimeOut, TimeUnit.SECONDS)
        builder.readTimeout(defaultReadTimeOut, TimeUnit.SECONDS)
        val commonInterceptor: HttpCommonInterceptor = HttpCommonInterceptor.Builder().build()
        builder.addInterceptor(commonInterceptor)
        builder.addInterceptor(BaseUrlInterceptor())

        mRetrofit = Retrofit.Builder()
            .client(builder.build())
            .addCallAdapterFactory(RxJava2CallAdapterFactory.create())
            .addConverterFactory(GsonConverterFactory.create())
            .baseUrl("https://www.wanandroid.com")
            .build()
    }

    /**
     * 创建service
     */
    fun <T> create(service: Class<T>): T {
        return mRetrofit!!.create(service)
    }
}